#include <SDL/SDL.h>
#include <stdio.h>
#include <GL/gl.h>
#include <GL/glu.h>
#include "lorenz.h"

SDL_Surface			*init_sdl(void)
{
	SDL_Surface		*window;

	if (SDL_Init(SDL_INIT_VIDEO) == -1)
	{
		fprintf(stderr, "Invalid return from SDL initialisation.\n");
		return (0);
	}
	if ((window = SDL_SetVideoMode(WIN_X, WIN_X, BPP, SDL_OPENGL)) == 0)
	{
		fprintf(stderr, "Invalid return from SDL initialisation.\n");
		return (0);
	}
	SDL_WM_SetCaption("Lorenz Attractor", NULL);
	SDL_WM_GrabInput(SDL_GRAB_ON);
    SDL_ShowCursor(SDL_DISABLE);
	return (window);
}

void			init_light(void)
{
	float MatSpec[4] = {1.0f, 1.0f, 1.0f, 1.0f};
	float MatDif[4] = {1.0f, 1.0f, 1.0f, 1.0f};
	float MatAmb[4] = {0.3f, 0.3f, 0.3f, 1.0f};
	float Light1Pos[4] = {0.0f, 500.0f, 0.0f, 1.0f};
	float Light1Dif[4] = {1.0f, 0.2f, 0.2f, 1.0f};
	float Light1Spec[4] = {1.0f, 0.2f, 0.2f, 1.0f};
	float Light1Amb[4] = {0.5f, 0.5f, 0.5f, 1.0f};

	glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, MatSpec);
	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MatDif);
	glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT, MatAmb);
	glLightfv(GL_LIGHT0, GL_DIFFUSE, Light1Dif);
	glLightfv(GL_LIGHT0, GL_SPECULAR, Light1Spec);
	glLightfv(GL_LIGHT0, GL_AMBIENT, Light1Amb);
	glLightfv(GL_LIGHT0, GL_POSITION, Light1Pos);
	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);
}

void			init_3f(t_3f *vect, float x, float y, float z)
{
    vect->x = x;
    vect->y = y;
    vect->z = z;
}

void			init_cam(t_cam *cam)
{
    cam->sensib = 0.1;
    cam->speed = 0.02;
    cam->key_state[0] = FALSE;
    cam->key_state[1] = FALSE;
    cam->key_state[2] = FALSE;
    cam->key_state[3] = FALSE;
    cam->theta = 0;
    cam->phi = 0;
    init_3f(&(cam->pos), 0, 0, 100);
    init_3f(&(cam->look), 0, 0, 0);
}

void			init_gl(t_cam *cam)
{
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    gluPerspective(70, (double)WIN_X / WIN_Y, 1, 1000);
    init_cam(cam);
	glMatrixMode(GL_MODELVIEW);
	glEnable(GL_DEPTH_TEST);
	init_light();
}
